@@ -1,7 +1,10 @@
+extern crate alloc;
+
 use crate::{
 	fields::{ConstantField, FunctionField, IdentityField, ScalarFieldWrapper},
 	MapField, ScalarField, TransformField,
 };
+use alloc::boxed::Box;
 use core::ops::{Add, BitAnd, BitOr, BitXor, Div, Mul, Neg, Not, Rem, Shl, Shr, Sub};
 
 macro_rules! binary_ops {
@@ -161,6 +164,10 @@ impl_ops! {
 		T::Scalar: Neg,
 }
 
+impl_ops! {
+	impl<P, S> Op for Box<dyn ScalarField<Point = P, Scalar = S>>
+	where
+}
 impl_ops! {
 	impl<I, S, F> Op for MapField<I, F>
 	where
